@@ -18,10 +18,11 @@ var Base = require('./base');
  * Dir constructor.
  *
  * @param {String|null} name
+ * @param {Object} [options] Overrides for directory naming
  */
-function Dir(name) {
-  this.init(name);
-};
+function Dir(name, options) {
+  this.init(name, options);
+}
 
 /**
  * Dir extends from tmp.
@@ -41,7 +42,7 @@ Dir.prototype.create = function(dirname) {
  * Asynchronous dir.
  */
 Dir.prototype.rmdir = function() {
-  fs.rmdir.apply(fs, this.prepareArgs(arguments));
+  fs.rmdir.apply(fs, this.prepareArgs(arguments, [function(err) {throw Error(err)}]));
 };
 
 /**
