@@ -55,7 +55,7 @@ File.prototype.readFileSync = function() {
  * Asynchronously writes data to a file.
  */
 File.prototype.writeFile = function() {
-  fs.writeFile.apply(fs, this.prepareArgs(arguments, ['', {}, function(err) {throw Error(err)}]));
+  fs.writeFile.apply(fs, this.prepareArgs(arguments, [{}, function(err) {throw Error(err)}]));
 };
 
 /**
